@@ -264,6 +264,7 @@ cffi_fptr_fn_pconst pattern_callback_2(cffi_fptr_fn_pconst callback);
 cffi_ffierror simple_service_destroy(cffi_simpleservice** context);
 cffi_ffierror simple_service_new_with(cffi_simpleservice** context, uint32_t some_value);
 cffi_ffierror simple_service_new_without(cffi_simpleservice** context);
+cffi_ffierror simple_service_new_with_string(cffi_simpleservice** context, uint8_t* ascii);
 cffi_ffierror simple_service_new_failing(cffi_simpleservice** context, uint8_t some_value);
 cffi_ffierror simple_service_method_result(cffi_simpleservice* context, uint32_t anon1);
 uint32_t simple_service_method_value(cffi_simpleservice* context, uint32_t x);
@@ -279,6 +280,7 @@ cffi_sliceu32 simple_service_return_slice(cffi_simpleservice* context);
 cffi_slicemutu32 simple_service_return_slice_mut(cffi_simpleservice* context);
 uint8_t* simple_service_return_string(cffi_simpleservice* context);
 cffi_ffierror simple_service_method_void_ffi_error(cffi_simpleservice* context);
+cffi_ffierror simple_service_method_callback(cffi_simpleservice* context, cffi_fptr_fn_u32_rval_u32 callback);
 cffi_ffierror simple_service_lt_destroy(cffi_simpleservicelifetime** context);
 cffi_ffierror simple_service_lt_new_with(cffi_simpleservicelifetime** context, uint32_t* some_value);
 void simple_service_lt_method_lt(cffi_simpleservicelifetime* context, cffi_slicebool slice);
@@ -1748,6 +1750,20 @@ class api:
         else:
             raise Exception(f"Function returned error {_rval}")
 
+    @staticmethod
+    def simple_service_new_with_string(context, ascii):
+        """"""
+        if hasattr(context, "_ctx"):
+            context = context.c_ptr()
+        if isinstance(ascii, bytes):
+            ascii = ascii_string(ascii)
+
+        _rval = _api.simple_service_new_with_string(context, ascii)
+        if _rval == FFIError.Ok:
+            return _rval
+        else:
+            raise Exception(f"Function returned error {_rval}")
+
     @staticmethod
     def simple_service_new_failing(context, some_value: int):
         """"""
@@ -1939,6 +1955,25 @@ class api:
         else:
             raise Exception(f"Function returned error {_rval}")
 
+    @staticmethod
+    def simple_service_method_callback(context, callback):
+        """"""
+        if hasattr(context, "_ctx"):
+            context = context.c_ptr()
+        _callback = callback
+
+        @ffi.callback(callbacks.fn_u32_rval_u32)
+        def _callback_callback(x):
+            return _callback(x)
+
+        callback = _callback_callback
+
+        _rval = _api.simple_service_method_callback(context, callback)
+        if _rval == FFIError.Ok:
+            return _rval
+        else:
+            raise Exception(f"Function returned error {_rval}")
+
     @staticmethod
     def simple_service_lt_destroy(context):
         """ Destroys the given instance.
@@ -2045,6 +2080,16 @@ class SimpleService(CHeapAllocated):
         self = SimpleService(SimpleService.__api_lock, ctx)
         return self
 
+    @staticmethod
+    def new_with_string(ascii) -> SimpleService:
+        """"""
+        if hasattr(ascii, "_ctx"):
+            ascii = ascii.c_ptr()
+        ctx = ffi.new("cffi_simpleservice**")
+        api.simple_service_new_with_string(ctx, ascii)
+        self = SimpleService(SimpleService.__api_lock, ctx)
+        return self
+
     @staticmethod
     def new_failing(some_value: int) -> SimpleService:
         """"""
@@ -2119,6 +2164,10 @@ class SimpleService(CHeapAllocated):
         """"""
         return api.simple_service_method_void_ffi_error(self.c_value(), )
 
+    def method_callback(self, callback):
+        """"""
+        return api.simple_service_method_callback(self.c_value(), callback)
+
 
 class SimpleServiceLifetime(CHeapAllocated):
     __api_lock = object()
